@@ -156,7 +156,7 @@ class configdb(object):
         for _i in [1, 2]:
             try:
                 cur = self._dbcon.cursor()
-                cur.execute("SELECT key FROM '%s' WHERE value=?" % section, (option,))
+                cur.execute("SELECT key FROM '%s' WHERE value=?" % section, (option,))  # noqa: S608
                 rows = cur.fetchall()
                 cur.close()
                 if rows:
@@ -171,7 +171,7 @@ class configdb(object):
         for _i in [1, 2]:
             try:
                 cur = self._dbcon.cursor()
-                cur.execute("SELECT value FROM '%s' WHERE key=?" % section, (option,))
+                cur.execute("SELECT value FROM '%s' WHERE key=?" % section, (option,))  # noqa: S608
                 rows = cur.fetchall()
                 cur.close()
                 if rows:
@@ -187,7 +187,7 @@ class configdb(object):
         val = [option, value]
         if section == "AD rejected":
             # update retry_count
-            cmd = "INSERT OR REPLACE INTO '%s' (key, value, retry_count) VALUES (?, ?, COALESCE((SELECT retry_count FROM '%s' WHERE key = ? )+1 ,0));" % (section, section)
+            cmd = "INSERT OR REPLACE INTO '%s' (key, value, retry_count) VALUES (?, ?, COALESCE((SELECT retry_count FROM '%s' WHERE key = ? )+1 ,0));" % (section, section)  # noqa: S608
             val = [option, value, option]
         for _i in [1, 2]:
             try:
@@ -206,7 +206,7 @@ class configdb(object):
         for _i in [1, 2]:
             try:
                 cur = self._dbcon.cursor()
-                cur.execute("SELECT * FROM '%s'" % (section))
+                cur.execute("SELECT * FROM '%s'" % (section))  # noqa: S608
                 rows = cur.fetchall()
                 cur.close()
                 return rows
@@ -220,7 +220,7 @@ class configdb(object):
         for _i in [1, 2]:
             try:
                 cur = self._dbcon.cursor()
-                cur.execute("DELETE FROM '%s' WHERE key=?" % section, (option,))
+                cur.execute("DELETE FROM '%s' WHERE key=?" % section, (option,))  # noqa: S608
                 self._dbcon.commit()
                 cur.close()
                 return
@@ -265,7 +265,7 @@ class configdb(object):
         for _i in [1, 2]:
             try:
                 cur = self._dbcon.cursor()
-                cur.execute("SELECT value FROM '%s' WHERE key=?" % section, (option,))
+                cur.execute("SELECT value FROM '%s' WHERE key=?" % section, (option,))  # noqa: S608
                 rows = cur.fetchall()
                 cur.close()
                 return bool(rows)
